summaryrefslogtreecommitdiffstats
path: root/kmymoney2/plugins/ofximport/ofximporterplugin.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/plugins/ofximport/ofximporterplugin.cpp')
-rw-r--r--kmymoney2/plugins/ofximport/ofximporterplugin.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmymoney2/plugins/ofximport/ofximporterplugin.cpp b/kmymoney2/plugins/ofximport/ofximporterplugin.cpp
index 77b790e..82919e0 100644
--- a/kmymoney2/plugins/ofximport/ofximporterplugin.cpp
+++ b/kmymoney2/plugins/ofximport/ofximporterplugin.cpp
@@ -93,7 +93,7 @@ TQString OfxImporterPlugin::formatFilenameFilter(void) const
bool OfxImporterPlugin::isMyFormat( const TQString& filename ) const
{
// filename is considered an Ofx file if it tqcontains
// the tag "<OFX>" or "<OFC>" in the first 20 lines
// which contain some data.
bool result = false;
@@ -108,8 +108,8 @@ bool OfxImporterPlugin::isMyFormat( const TQString& filename ) const
{
// get a line of data and remove all unnecessary whitepace chars
TQString line = ts.readLine().simplifyWhiteSpace();
- if ( line.tqcontains("<OFX>",false)
- || line.tqcontains("<OFC>",false) )
+ if ( line.contains("<OFX>",false)
+ || line.contains("<OFC>",false) )
result = true;
// count only lines that contains some non white space chars
if(!line.isEmpty())
@@ -93,7 +93,7 @@ TQString OfxImporterPlugin::formatFilenameFilter(void) const
bool OfxImporterPlugin::isMyFormat( const TQString& filename ) const
{
- // filename is considered an Ofx file if it tqcontains
+ // filename is considered an Ofx file if it contains
// the tag "<OFX>" or "<OFC>" in the first 20 lines
// which contain some data.